state_dict = {
    'Johor': [1, 21, 22, 23, 24],
    'Kedah': [2, 25, 26, 27],
    'Kelantan': [3, 28, 29],
    'Malacca': [4, 30],
    'Negeri Sembilan': [5, 31, 59],
    'Pahang': [6, 32, 33],
    'Penang': [7, 34, 35],
    'Perak': [8, 36, 37, 38, 39],
    'Perlis': [9, 40],
    'Selangor': [10, 41, 42, 43, 44],
    'Terengganu': [11, 45, 46],
    'Sabah': [12, 47, 48, 49],
    'Sarawak': [13, 50, 51, 52 ,53],
    'Federal Territory of Kuala Lumpur': [14, 54, 55, 56, 57],
    'Federal Territory of Labuan': [15, 58],
    'Federal Territory of Putrajaya': [16],
}

abbreviation_dict = {
    'Johor': 'JHR',
    'Kedah': 'KDH',
    'Kelantan': 'KTN',
    'Malacca': 'MLK',
    'Negeri Sembilan': 'NSN',
    'Pahang': 'PHG',
    'Penang': 'PNG',
    'Perak': 'PRK',
    'Perlis': 'PLS',
    'Sabah': 'SBH',
    'Sarawak': 'SWK',
    'Selangor': 'SGR',
    'Terengganu': 'TGR',
    'Kuala Lumpur': 'KUL',
    'Labuan': 'LBN',
    'Putrajaya': 'PJY'
}
